from src.gpt3_simple_primer.generator import GPT3Generator, set_api_key
from src.gpt3_simple_primer.examples import birthday_finder, book_summarizer, idiom_explainer
